@@ -1,9 +1,8 @@
 ;;; mmm-mason.el --- MMM submode class for Mason components
 
-;; Copyright (C) 2000 by Michael Abraham Shulman
+;; Copyright (C) 2000-2003, 2013, 2018  Free Software Foundation, Inc.
 
-;; Author: Michael Abraham Shulman <viritrilbia@users.sourceforge.net>
-;; Version: $Id: mmm-mason.el,v 1.13 2003/03/09 17:04:03 viritrilbia Exp $
+;; Author: Michael Abraham Shulman <viritrilbia@gmail.com>
 
 ;;{{{ GPL
 
@@ -167,10 +166,10 @@ Saves the name of the tag matched.")
 
 (defun mmm-mason-set-mode-line ()
   (setq mmm-buffer-mode-display-name "Mason"))
-(add-hook 'mmm-mason-class-hook 'mmm-mason-set-mode-line)
+(add-hook 'mmm-mason-class-hook #'mmm-mason-set-mode-line)
 
 ;;}}}
 
 (provide 'mmm-mason)
 
-;;; mmm-mason.el ends here
\ No newline at end of file
+;;; mmm-mason.el ends here
