@@ -1,6 +1,6 @@
 ;;; mmm-vars.el --- Variables for MMM Mode
 
-;; Copyright (C) 2000-2004, 2011-2015, 2018  Free Software Foundation, Inc.
+;; Copyright (C) 2000-2004, 2011-2015, 2018-2020  Free Software Foundation, Inc.
 
 ;; Author: Michael Abraham Shulman <viritrilbia@gmail.com>
 
@@ -108,7 +108,8 @@
 ;;{{{ Save Local Variables
 
 (defvar mmm-c-derived-modes
-  '(c-mode c++-mode objc-mode pike-mode java-mode jde-mode javascript-mode
+  '(c-mode c++-mode objc-mode pike-mode java-mode jde-mode
+    js-mode typescript-mode
     php-mode))
 
 (defvar mmm-save-local-variables
@@ -151,7 +152,7 @@
     ,@(mapcar
        (lambda (var) (list var nil mmm-c-derived-modes))
        '(c++-template-syntax-table
-	 c-<-op-cont-regexp 
+         c-<-op-cont-regexp
 	 c->-op-cont-regexp
          c-after-brace-list-key
 	 c-after-suffixed-type-decl-key
@@ -173,11 +174,11 @@
 	 c-block-stmt-2-kwds
 	 c-brace-list-key
          c-case-kwds-regexp
-	 c-cast-parens 
+         c-cast-parens
 	 c-class-key
 	 c-class-kwds
 	 c-cleanup-list
-	 c-colon-type-list-re 
+         c-colon-type-list-re
 	 c-comment-only-line-offset
 	 c-comment-prefix-regexp
 	 c-comment-start-regexp
@@ -200,9 +201,9 @@
 	 c-hanging-comment-ender-p
 	 c-hanging-comment-starter-p
 	 c-hanging-semi\&comma-criteria
-	 c-identifier-key 
+         c-identifier-key
 	 c-identifier-last-sym-match
-	 c-identifier-start 
+         c-identifier-start
 	 c-identifier-syntax-modifications
 	 c-identifier-syntax-table
 	 c-in-comment-lc-prefix
@@ -219,24 +220,24 @@
 	 c-label-kwds-regexp
 	 c-label-minimum-indentation
 	 c-lambda-kwds
-	 c-literal-start-regexp 
+         c-literal-start-regexp
 	 c-macro-with-semi-re
          c-nonlabel-token-key
          c-nonlabel-token-2-key
-	 c-nonsymbol-chars 
+         c-nonsymbol-chars
 	 c-nonsymbol-token-regexp
 	 c-not-decl-init-keywords
 	 c-offsets-alist
-	 c-opt-<>-arglist-start 
+         c-opt-<>-arglist-start
 	 c-opt-<>-arglist-start-in-paren
-	 c-opt-<>-sexp-key 
+         c-opt-<>-sexp-key
 	 c-opt-access-key
 	 c-opt-asm-stmt-key
 	 c-opt-bitfield-key
 	 c-opt-block-decls-with-vars-key
 	 c-opt-block-stmt-key
-	 c-opt-cpp-prefix 
-	 c-opt-cpp-start 
+         c-opt-cpp-prefix
+         c-opt-cpp-start
 	 c-opt-decl-spec-key
 	 c-opt-friend-key
 	 c-opt-identifier-concat-key
@@ -247,48 +248,48 @@
 	 c-opt-method-key
 	 c-opt-postfix-decl-spec-key
 	 c-opt-type-component-key
-	 c-opt-type-concat-key 
-	 c-opt-type-modifier-key 
-	 c-opt-type-suffix-key 
+         c-opt-type-concat-key
+         c-opt-type-modifier-key
+         c-opt-type-suffix-key
 	 c-other-decl-block-key
 	 c-other-decl-block-kwds
 	 c-other-decl-kwds
 	 c-overloadable-operators-regexp
-	 c-paragraph-separate 
-	 c-paragraph-start 
-	 c-paren-stmt-key 
-	 c-primary-expr-regexp 
-	 c-primitive-type-key 
+         c-paragraph-separate
+         c-paragraph-start
+         c-paren-stmt-key
+         c-primary-expr-regexp
+         c-primitive-type-key
 	 c-primitive-type-kwds
 	 c-protection-kwds
          c-postfix-decl-spec-key
-	 c-recognize-<>-arglists 
+         c-recognize-<>-arglists
 	 c-recognize-knr-p
-	 c-recognize-paren-inits 
+         c-recognize-paren-inits
 	 c-recognize-typeless-decls
 	 c-regular-keywords-regexp
-	 c-simple-stmt-key 
+         c-simple-stmt-key
 	 c-simple-stmt-kwds
 	 c-special-brace-lists
-	 c-specifier-key 
+         c-specifier-key
 	 c-specifier-kwds
-	 c-stmt-delim-chars 
+         c-stmt-delim-chars
 	 c-stmt-delim-chars-with-comma
          c-symbol-char-key
 	 c-symbol-key
-	 c-symbol-start 
+         c-symbol-start
 	 c-syntactic-eol
-	 c-syntactic-ws-end 
-	 c-syntactic-ws-start 
-	 c-type-decl-prefix-key 
-	 c-type-decl-suffix-key 
+         c-syntactic-ws-end
+         c-syntactic-ws-start
+         c-type-decl-prefix-key
+         c-type-decl-suffix-key
 	 c-type-prefix-key
          c-typeof-key
          c-prefix-spec-kwds-re
          c-typedef-key
 	 c-typedef-decl-key
-	 comment-end 
-	 comment-start 
+         comment-end
+         comment-start
 	 comment-start-skip))
     ,@(mapcar
        (lambda (var) (list var nil '(js-mode)))
@@ -301,6 +302,7 @@
     local-abbrev-table
     ;; And finally the syntax table and local map.
     ((syntax-table . set-syntax-table) buffer)
+    (syntax-ppss-table buffer)
     ((current-local-map . use-local-map) buffer)
     paragraph-separate
     paragraph-start
@@ -1047,7 +1049,7 @@ The CLASSES are all made private, i.e. non-user-visible."
 ;;}}}
 ;;{{{ Version Number
 
-(defconst mmm-version "0.5.7"
+(defconst mmm-version "0.5.8"
   "Current version of MMM Mode.")
 
 (defun mmm-version ()
